@@ -58,6 +58,8 @@ from google.cloud.bigquery_migration_v2.types.translation_config import (
     ObjectNameMapping,
     ObjectNameMappingList,
     OracleDialect,
+    PostgresqlDialect,
+    PrestoDialect,
     RedshiftDialect,
     SnowflakeDialect,
     SourceEnv,
@@ -100,6 +102,8 @@ __all__ = (
     "ObjectNameMapping",
     "ObjectNameMappingList",
     "OracleDialect",
+    "PostgresqlDialect",
+    "PrestoDialect",
     "RedshiftDialect",
     "SnowflakeDialect",
     "SourceEnv",
