@@ -47,6 +47,8 @@ from .types.translation_config import (
     ObjectNameMapping,
     ObjectNameMappingList,
     OracleDialect,
+    PostgresqlDialect,
+    PrestoDialect,
     RedshiftDialect,
     SnowflakeDialect,
     SourceEnv,
@@ -84,6 +86,8 @@ __all__ = (
     "ObjectNameMappingList",
     "OracleDialect",
     "Point",
+    "PostgresqlDialect",
+    "PrestoDialect",
     "RedshiftDialect",
     "ResourceErrorDetail",
     "SQLServerDialect",
